
/*mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm
m
m			SVGA256 GRAPHICS LIBRARY
m 	     Copyright (C) 1993 by Orthware.   All rights reserved.
mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm
m
m 	SVGA256.h   	Header file for the SVGA256 Graphics Library. 
m
mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm*/

#ifndef SVGA256_H	/* only "see" this include file once for compilation */
#define SVGA256_H


/********************************/
/* Miscellaneous definitions	*/
/********************************/

/* pixel plotting methods */
#define PUT_MODE	0
#define XOR_MODE	1

/* defines for character fonts 8x8(low 128), 8x8(high 128), 8x14, 8x16 */
#define FONT8a		3
#define FONT8b		4
#define FONT14		2
#define FONT16		6
#define FONTDEFAULT	FONT14

/* the values returned by "SV_getprocessor()" */
#define P_80386         7		/* also for 80486 */
#define P_80286         6
#define P_80186         5
#define P_80188         4
#define P_v30           3
#define P_v20           2
#define P_8086          1
#define P_8088          0


/* defs for the different methods of screen-saving used by windowing routines */
#define NONE_BLOCKSAVES		0
#define XMEM_BLOCKSAVES		1
#define VIDEO_BLOCKSAVES	2
#define	RAM_BLOCKSAVES		3

/* number of dac registers:  256 (colors) * 3 registers each (R,G,B) = 768 */
#define DACREGS		768

/* a macro to combine Bkgd and Foreground color into a single unsigned int */
#define SV_BF(x, y)	(((unsigned int) x << 8) | (unsigned int) y)


#ifdef __cplusplus
  #define EXTERN extern "C"	/* for C routines called from C++ modules */ 
#else
  #define EXTERN extern		/* for C routines called from C modules */
#endif


/****************************************************
/* Function Declarations for routines in s256low.asm
/***************************************************/

EXTERN int  far SV_vgacard(void);
EXTERN void far SV_init320x200(void);
EXTERN void far SV_BIOSsetgmode(int modenum);
EXTERN int  far SV_BIOSgetgmode(void);
EXTERN int  far SV_getVESAmode(void);
EXTERN int  far SV_setVESAmode(int mode);
EXTERN int  far SV_vesabiosexists(void);
EXTERN int  far SV_initVESA256(int mode);
EXTERN int  far SV_setVESA256mode(int mode);
EXTERN int  far SV_initTSENG(int mode);
EXTERN int  far SV_setTSENGmode(int mode);
EXTERN void far SV_readDAC(int start_dac,int dac_set_ct,
			unsigned char far *array);
EXTERN void far SV_writeDAC(int start_dac,int dac_set_ct,
			unsigned char far *array);
EXTERN void far SV_putimage(unsigned char far *image, int xstart,
			int ystart, int width, int ht, int zoom_factor);
EXTERN void far SV_getimage(unsigned char far *image, int xstart,
			int ystart, int width, int ht);
EXTERN void far SV_moveimage(int fromX, int fromY, int toX, 
			int toY, int Width, int Height);
EXTERN void far SV_invertimagebuffer(unsigned char far *image, 
			int width, int ht);
EXTERN void far SV_setfont(int fontnum);
EXTERN int  far SV_getfont(void);
EXTERN int  far SV_getprocessor(void);
EXTERN void far SV_putchar(int asciicode, int x, int y, int color);
EXTERN void far SV_putstringxy(char far *string, int x, int y, int color);
EXTERN void far SV_putstring(char far *string);
EXTERN void far SV_movetoxy(int x, int y);
EXTERN void far SV_moverelxy(int dx, int dy);
EXTERN int  far SV_getx(void);
EXTERN int  far SV_gety(void);
EXTERN void far SV_setcolor(int color);
EXTERN int  far SV_getcolor(void);
EXTERN void far SV_scanline(int x0, int x1, int y, int color);
EXTERN void far SV_line(int x0, int y0, int x1, int y1, int color);
EXTERN void far SV_lineto(int x, int y);
EXTERN void far SV_linerel(int x, int y);
EXTERN void far SV_rectangle(int lt, int top, int rt, int bot, int color);
EXTERN void far SV_drawpoly(int numpoints, int far *points);
EXTERN int  far SV_xmax(void);
EXTERN int  far SV_ymax(void);
EXTERN int  far SV_xres(void);
EXTERN int  far SV_yres(void);
EXTERN int  far SV_charht(void);
EXTERN int  far SV_charwidth(void);
EXTERN void far SV_writepixel(int x, int y, int color);
EXTERN int  far SV_readpixel(int x, int y);
EXTERN void far SV_fillpage(int page, int color);
EXTERN void far SV_clearscreen(int color);
EXTERN void far SV_fillrect(int lt, int top, int rt, int bot, int color);
EXTERN void far SV_setlinemode(int line_mode);
EXTERN void far SV_setlinewidth(int line_width);
EXTERN void far SV_setlinestyle(int line_style);
EXTERN int  far SV_getlinemode(void);
EXTERN int  far SV_getlinewidth(void);
EXTERN int  far SV_getlinestyle(void);
EXTERN void far SV_putbitpattern(unsigned char far *pattern, 
		int xcoord, int ycoord, int width, int ht, int mode, int color);
EXTERN void far SV_putbytepattern(unsigned char far *pattern, int xcoord,
			int ycoord, int width, int ht, int mode);
EXTERN int  far SV_getcharsize(void);
EXTERN void far SV_setcharsize(int char_size_factor);
EXTERN int  far SV_videopages(void);
EXTERN void far SV_microsecdelay(unsigned long microsecs);
EXTERN int  far SV_seteventtimer(unsigned long microsecs,
			unsigned char far *event);
EXTERN void far SV_canceleventtimer(void);
EXTERN int  far SV_detectxmem(void);
EXTERN int  far SV_initxmem(void);
EXTERN unsigned int far SV_allocxmem(unsigned long numbytes);
EXTERN int  far SV_freexmem(unsigned int handle);
EXTERN unsigned long far SV_contigxmem(void);
EXTERN unsigned long far SV_availxmem(void);
EXTERN int  far SV_lockxmem(unsigned int handle);
EXTERN int  far SV_unlockxmem(unsigned int handle);
EXTERN int  far SV_unlockxmem(unsigned int handle);
EXTERN int  far SV_readxmem(unsigned xmemhandle, unsigned long xmemoffset,
			       unsigned numbytes, void far *destaddr);
EXTERN int  far SV_writexmem(unsigned xmemhandle, unsigned long xmemoffset,
			       unsigned numbytes, void far *destaddr);


/****************************************************
/* Function Declarations for routines in s256xmem.c
/***************************************************/

EXTERN int  far SV_himeminitialized(void);
EXTERN int  far SV_inithimem(int numhandles);
EXTERN int  far SV_himemexists(void);
EXTERN unsigned long far SV_availhimem(void);
EXTERN unsigned long far SV_contighimem(void);
EXTERN int  far SV_allochimem(unsigned long size);
EXTERN int  far SV_freehimem(int hinum);
EXTERN void far SV_freeallhimem(void);
EXTERN int  far SV_writehimem(int hinum, unsigned long hioffset, 
		unsigned long bytect, unsigned char far *lowmembuff);
EXTERN int  far SV_readhimem(int hinum, unsigned long hioffset, 
		unsigned long bytect, unsigned char far *lowmembuff);



/****************************************************
/* Function Declarations for routines in s256high.c
/***************************************************/

EXTERN void far SV_circle(int x0, int y0, int r, int color);
EXTERN void far SV_ellipse(int x, int y, int b, int color, float aspect);
EXTERN void far SV_fillellipse(int x, int y, int b, int color, float aspect);
EXTERN void far SV_fillcircle(int x, int y, int b, int color);
EXTERN void far SV_framedrect(int lt, int top, int rt,
		int bot, int frame_color, int fill_color);
EXTERN int  far SV_setgmode(int mode);
EXTERN int  far SV_getgmode(void);
EXTERN void far SV_screenborder(int color);
EXTERN void far SV_msecdelay(unsigned short msec);



/****************************************************
/* Function Declarations for routines in s256char.c
/***************************************************/

EXTERN int  far SV_setcharorigin(int x, int y);
EXTERN void far SV_lastcharorigin(void);
EXTERN void far SV_getcharorigin(int far *x,  int far *y);
EXTERN void far SV_charmoveto(int chc, int chr);
EXTERN int  far SV_charmaxrow(void);
EXTERN int  far SV_charmaxcol(void);
EXTERN int  far SV_charx(int chc);
EXTERN int  far SV_chary(int chr);
EXTERN int  far SV_stringwidth(char far *string);
EXTERN void far SV_clearstring(int length, int fillcolor);
EXTERN void far SV_savecharstate(void);
EXTERN void far SV_restorecharstate(void);



/****************************************************
/* Function Declarations for routines in s256clr.c
/***************************************************/

EXTERN void far SV_initgrayscale64(int half, int r_flag);
EXTERN void far SV_setbkcolor(int color);
EXTERN void far SV_setDAC(int DAC_set_index, int red, int green,int blue);
EXTERN void far SV_fadeout(int steps, int delaymsecs);
EXTERN void far SV_fadein(int steps, int delaymsecs);
EXTERN void far SV_fadewriteDAC(int start_dac, int dac_set_ct, 
			unsigned char far *array);



/****************************************************
/* Function Declarations for routines in s256wind.c
/***************************************************/

EXTERN int  far SV_windowsinitialized(void);
EXTERN int  far SV_initwindows(int maxwinds, int Kbytes, int method1,
		int method2, int method3);
EXTERN int  far SV_saveblock(int lt, int top, int rt, int bot);
EXTERN int  far SV_restoreblock(int blocknum);
EXTERN int  far SV_freeblock(int blocknum);
EXTERN void far SV_freeallblocks(void);
EXTERN int  far SV_closeblock(int blocknum);
EXTERN int  far SV_getblockcoords(int blocknum, int far *lt, int far *top, 
		int far *rt, int far *bot);
EXTERN int  far SV_extrascanlines(void);
EXTERN int  far SV_openwind(int charcoords, int lt, int top, int rt, int bot,
			int framecolor, int fillcolor, int shadowcolor);
EXTERN int  far SV_closewind(int wnum);
EXTERN int  far SV_getwindcoords(int wnum, int far *lt, int far *top, 
			int far *rt, int far *bot);
EXTERN int  far SV_hidewind(int wnum);
EXTERN int  far SV_unhidewind(int wnum);
EXTERN int  far SV_freewind(int wnum);
EXTERN void far SV_freeallwinds(void);
EXTERN int  far SV_blockexists(int bnum);
EXTERN int  far SV_windexists(int wnum);



#endif		/* This header file is done being defined */
